@@ -83,10 +83,18 @@ class Subject(Base):
 
 
 class EducType(Base):
+    """
+    Тип обучения
+    """
     __tablename__ = 'univer_educ_type'
 
+    # Идентификатор
     id = Column('educ_type_id', Integer, primary_key=True)
+
+    # Наименование
     name_ru = Column('educ_type_name_ru', String(100))
+    name_kz = Column('educ_type_name_kz', String(100))
+    name_en = Column('educ_type_name_en', String(100))
 
     def __repr__(self):
         return '<EducType {}>'.format(self.name_ru)
@@ -313,6 +321,11 @@ class EducPlanPos(Base):
     # Статус
     status = Column(Integer)
 
+    # Группа позиции учебного плана
+    pos_group_id = Column(ForeignKey(
+        'univer_educ_plan_pos_groups.pos_group_id'))
+    pos_group = relationship('EducPlanPosGroup')
+
     def __repr__(self):
         return "<EducPlanPos {}: {} ({} семестр)>".format(self.educ_plan, self.subject, self.semester)
 
@@ -1002,3 +1015,30 @@ class District(Base):
 
     def __str__(self):
         return f'{self.name_ru}'
+
+
+class EducPlanPosGroup(Base):
+    """
+    Группа позиции учебного плана
+    """
+
+    # Идентификатор
+    id = Column('pos_group_id', Integer, primary_key=True)
+
+    # Учебный план
+    educ_plan_id = Column(ForeignKey('univer_educ_plan.educ_plan_id'))
+    educ_plan = relationship('EducPlan')
+
+    # Семестр позиции учебного плана
+    educ_plan_pos_semester = Column(Integer)
+
+    # Наименование
+    name_ru = Column('pos_group_name_ru', String)
+    name_kz = Column('pos_group_name_kz', String)
+    name_en = Column('pos_group_name_en', String)
+
+    def __repr__(self):
+        return f'<EducPlanPosGroup {self} (id={self.id} educ_plan_id={self.educ_plan_id})>'
+
+    def __str__(self):
+        return self.name_ru
