@@ -15,9 +15,8 @@ def get_session(config):
     engine.connect()
 
     session_factory = sessionmaker(bind=engine)
-    session = scoped_session(session_factory)
 
-    return session
+    return session_factory
 
 
 def get_base():
